@@ -11,27 +11,43 @@ from lpd.trainer import Trainer
 from lpd.callbacks import EpochEndStats, SchedulerStep
 from lpd.extensions.custom_schedulers import DoNothingToLR
 from lpd.extensions.custom_layers import Dense
-import lpd.callbacks as cbs 
+import lpd.enums as en 
 import lpd.utils.torch_utils as tu
 import lpd.utils.general_utils as gu
 
-# Create random Tensors to hold inputs and outputs
+def get_parameters():
+    # N is batch size; D_in is input dimension;
+    # H is hidden dimension; D_out is output dimension.
+    N, D_in, H, D_out = 64, 1000, 100, 10
+    num_epochs = 50
+    data_loader = data_generator(N, D_in, D_out)
+    data_loader_steps = 100
+    return N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps
+
 def data_generator(N, D_in, D_out):
+    # Create random Tensors to hold inputs and outputs
     x = T.randn(N, D_in)
     y = T.randn(N, D_out)
     while True:
         yield [x], y #YIELD THE SAME X,y every time
 
-def get_trainer(D_in, H, D_out, data_loader, data_loader_steps, num_epochs):
+def get_basic_model(D_in, H, D_out):
+    return nn.Sequential(
+                            Dense(D_in, H, use_bias=True, activation=F.relu),
+                            Dense(H, D_out, use_bias=True, activation=None)
+                        )
+
+def get_loss(device):
+    return nn.MSELoss(reduction='sum').to(device)
+
+def get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps):
+
     device = tu.get_gpu_device_if_available()
 
     # Use the nn package to define our model and loss function.
-    model = nn.Sequential(
-                            Dense(D_in, H, use_bias=True, activation=F.relu),
-                            Dense(H, D_out, use_bias=True, activation=None)
-                        ).to(device)
+    model = get_basic_model(D_in, H, D_out).to(device)
 
-    loss_func = nn.MSELoss(reduction='sum')
+    loss_func = get_loss(device)
    
     optimizer = optim.Adam(model.parameters(), lr=1e-4)
 
@@ -41,7 +57,7 @@ def get_trainer(D_in, H, D_out, data_loader, data_loader_steps, num_epochs):
 
     callbacks = [   
                     SchedulerStep(),
-                    EpochEndStats(cb_phase=cbs.CB_ON_EPOCH_END, round_values_on_print_to=7)
+                    EpochEndStats(cb_phase=en.CallbackPhase.ON_EPOCH_END, round_values_on_print_to=7)
                 ]
 
     trainer = Trainer(model=model, 
@@ -62,14 +78,9 @@ def get_trainer(D_in, H, D_out, data_loader, data_loader_steps, num_epochs):
 def run():
     gu.seed_all(42)  # BECAUSE ITS THE ANSWER TO LIFE AND THE UNIVERSE
 
-    # N is batch size; D_in is input dimension;
-    # H is hidden dimension; D_out is output dimension.
-    N, D_in, H, D_out = 64, 1000, 100, 10
-    num_epochs = 50
-    data_loader = data_generator(N, D_in, D_out)
-    data_loader_steps = 100
+    N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps = get_parameters()
 
-    trainer = get_trainer(D_in, H, D_out, data_loader, data_loader_steps, num_epochs)
+    trainer = get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps)
     
     trainer.summary()
 
