@@ -5,7 +5,7 @@ import torch.optim as optim
 
 import lpd.utils.torch_utils as tu
 from lpd.extensions.custom_layers import TransformerEncoderStack, Attention, MatMul2D
-import lpd.callbacks as cbs 
+import lpd.enums as en 
 from lpd.callbacks import EpochEndStats, ModelCheckPoint, Tensorboard, EarlyStopping, SchedulerStep
 from lpd.extensions.custom_metrics import binary_accuracy_with_logits
 from lpd.trainer import Trainer
@@ -77,7 +77,6 @@ def get_trainer(config,
 
     # scheduler = DoNothingToLR(optimizer=optimizer)
     scheduler = optim.lr_scheduler.ReduceLROnPlateau(optimizer, mode='min', patience=config.EARLY_STOPPING_PATIENCE // 2, verbose=True) # needs SchedulerStep callback WITH scheduler_parameters_func
-    # scheduler = optim.lr_scheduler.StepLR(optimizer=optimizer, gamma=config.STEP_LR_GAMMA, step_size=config.STEP_LR_STEP_SIZE) # needs SchedulerStep callback WITHOUT scheduler_parameters_func
     
     loss_func = nn.BCEWithLogitsLoss().to(device)
 
@@ -88,7 +87,7 @@ def get_trainer(config,
                     ModelCheckPoint(checkpoint_dir, checkpoint_file_name, monitor='val_loss', save_best_only=True, round_values_on_print_to=7), 
                     Tensorboard(summary_writer_dir=summary_writer_dir),
                     EarlyStopping(patience=config.EARLY_STOPPING_PATIENCE, monitor='val_loss'),
-                    EpochEndStats(cb_phase=cbs.CB_ON_EPOCH_END, round_values_on_print_to=7) # BETTER TO PUT IT LAST (MAKES BETTER SENSE IN THE LOG PRINTS)
+                    EpochEndStats(cb_phase=en.CallbackPhase.ON_EPOCH_END, round_values_on_print_to=7) # BETTER TO PUT IT LAST (MAKES BETTER SENSE IN THE LOG PRINTS)
                 ]
 
     trainer = Trainer(model=model, 
